import videojs from 'video.js';
const Button = videojs.getComponent('Button');  // eslint-disable-line

/**
 * The initial play button that shows before the video has played. The hiding of the
 * `BigPlayButton` get done via CSS and `Player` states.
 *
 * @extends Button
 */
class ForwardButton extends Button {

  /**
   * The constructor
   *
   * @param {Player} player
   *        The `Player` that this class should be attached to.
   *
   * @param {Object} [options]
   *        Object of option names and values.
   */
  constructor(player, options) {
    super(player, options);

    this.secs_ = 10;
  }

  /**
   * Builds the default DOM `className`.
   *
   * @return {string}
   *         The DOM `className` for this object. Always returns 'vjs-big-play-button'.
   */
  buildCSSClass() {
    return `vjs-forward-10-control ${super.buildCSSClass()}`;
  }

  /**
   * This gets called when a `BigPlayButton` "clicked". See {@link ClickableComponent}
   * for more detailed information on what a click can be.
   *
   * @param {EventTarget~Event} event
   *        The `keydown`, `tap`, or `click` event that caused this function to be
   *        called.
   *
   * @listens tap
   * @listens click
   */
  handleClick(event) {

    let time = this.player().currentTime() + this.secs_;

    if (time < 0) {
      time = 0;
    }

    this.player().currentTime(time);

  }

}

/**
 * The text that should display over the `BigPlayButton`s controls.
 * Added to for localization.
 *
 * @type {string}
 * @private
 */
ForwardButton.prototype.controlText_ = 'Forward Button';

export default ForwardButton;
