import videojs from 'video.js';
import {version as VERSION} from '../package.json';

const Plugin = videojs.getPlugin('plugin');

import ReplayButton from './replay-button';
import ForwardButton from './forward-button';
const Component = videojs.getComponent('Component');

// Default options for the plugin.
const defaults = {};

// Register the Components
Component.registerComponent('ReplayButton', ReplayButton);
Component.registerComponent('ForwardButton', ForwardButton);

/**
 * An advanced Video.js plugin. For more information on the API
 *
 * See: https://blog.videojs.com/feature-spotlight-advanced-plugins/
 */
class Replayforward extends Plugin {

  /**
   * Create a Replayforward plugin instance.
   *
   * @param  {Player} player
   *         A Video.js Player instance.
   *
   * @param  {Object} [options]
   *         An optional options object.
   *
   *         While not a core part of the Video.js plugin architecture, a
   *         second argument of options is a convenient way to accept inputs
   *         from your plugin's caller.
   */
  constructor(player, options) {
    // the parent class will add player under this.player
    super(player);

    this.options = videojs.mergeOptions(defaults, options);

    this.player.ready(() => {
      this.player.addClass('vjs-replayforward');
    });
  }
}

// Define default values for the plugin's `state` object here.
Replayforward.defaultState = {};

// Include the version number.
Replayforward.VERSION = VERSION;

// Register the plugin with video.js.
videojs.registerPlugin('replayforward', Replayforward);

export default Replayforward;
